/*
 *   Copyright (C) Christian Schulte, 2005-206
 *   All rights reserved.
 *
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 *
 *     o Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *     o Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 *
 *   THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 *   AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 *   THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *   $JOMC: IllegalServicesModletProvider.java 3851 2011-10-10 16:25:09Z schulte2005 $
 *
 */
package org.jomc.modlet.test.support;

import org.jomc.modlet.ModelContext;
import org.jomc.modlet.ModelException;
import org.jomc.modlet.ModelProcessor;
import org.jomc.modlet.ModelProvider;
import org.jomc.modlet.ModelValidator;
import org.jomc.modlet.Modlet;
import org.jomc.modlet.ModletProvider;
import org.jomc.modlet.Modlets;
import org.jomc.modlet.Service;
import org.jomc.modlet.Services;

/**
 * {@code ModletProvider} test implementation providing incompatible services.
 *
 * @author <a href="mailto:schulte2005@users.sourceforge.net">Christian Schulte</a> 1.0
 * @version $JOMC: IllegalServicesModletProvider.java 3851 2011-10-10 16:25:09Z schulte2005 $
 */
public final class IllegalServicesModletProvider implements ModletProvider
{

    public IllegalServicesModletProvider()
    {
        super();
    }

    public Modlets findModlets( final ModelContext context ) throws ModelException
    {
        final Modlets modlets = new Modlets();
        final Modlet modlet = new Modlet();
        modlets.getModlet().add( modlet );
        modlet.setName( IllegalServicesModletProvider.class.getName() );
        modlet.setModel( IllegalServicesModletProvider.class.getName() );
        modlet.setServices( new Services() );

        Service s = new Service();
        s.setClazz( Object.class.getName() );
        s.setIdentifier( ModelProvider.class.getName() );
        modlet.getServices().getService().add( s );

        s = new Service();
        s.setClazz( Object.class.getName() );
        s.setIdentifier( ModelProcessor.class.getName() );
        modlet.getServices().getService().add( s );

        s = new Service();
        s.setClazz( Object.class.getName() );
        s.setIdentifier( ModelValidator.class.getName() );
        modlet.getServices().getService().add( s );

        s = new Service();
        s.setClazz( Object.class.getName() );
        s.setIdentifier( "javax.xml.bind.Marshaller.Listener" );
        modlet.getServices().getService().add( s );

        s = new Service();
        s.setClazz( Object.class.getName() );
        s.setIdentifier( "javax.xml.bind.Unmarshaller.Listener" );
        modlet.getServices().getService().add( s );

        context.setAttribute( IllegalServicesModletProvider.class.getName(), this );
        return modlets;
    }

}
